/* twpsk  - A gui application for PSK
 * Copyright (C) 1999-2006 Ted Williams WA0EIR 
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139,
 * USA.
 *
 * Version: 3.0 - Jul 2008
 */

#ifndef INCLUDE_CALLBOX_H
#define INCLUDE_CALLBOX_H

#include "GUI.h"
#include <Xm/SelectioB.h>
#include <Xm/MessageB.h>
#include <sys/shm.h>

#define HEIGHT   120
#define WIDTH    90
//#define KEY      6146     /* Some nice number */
//#define SHMSIZE  40       /* Size of shared memory */

/*
 * Callbox class
 */

class Callbox
{
   private:
      int  shmid;               /* IPC ID for shared memory */

      Widget callShell, callBox, clearPB, callTF;

      static void clearCB (Widget w, XtPointer cdata, XtPointer cbs);
      static void callCB (Widget w, XtPointer cdata, XtPointer cbs);

   public:
      Callbox (Widget shell);
      void quiet() {};

};
#endif
